@@ -7,6 +7,7 @@ from pygeoogc import (
     MissingInputs,
     RetrySession,
     ServerError,
+    ThreadingException,
     ZeroMatched,
 )
 
@@ -21,6 +22,15 @@ def test_server_error():
         server_error()
 
 
+def threading_exception():
+    raise ThreadingException(4, "Failed")
+
+
+def test_threading_exception():
+    with pytest.raises(ThreadingException):
+        threading_exception()
+
+
 def zero_matched():
     raise ZeroMatched("Query returned no matched objects.")
 
@@ -58,7 +68,7 @@ def test_missing_input():
 
 
 def get_connection_error():
-    url = "http://somefailedurl.com"
+    url = "https://somefailedurl.com"
     s = RetrySession(retries=2)
     s.get(url)
 
@@ -69,7 +79,7 @@ def test_get_connection_error():
 
 
 def post_connection_error():
-    url = "http://somefailedurl.com"
+    url = "https://somefailedurl.com"
     s = RetrySession(retries=2)
     s.post(url)
 
